==> kubernetes-model-kustomize-6.5.0-sources.jar: io/fabric8/kubernetes/api/model/kustomize/v1beta1/LegacySortOptionsFluent.java <==
package io.fabric8.kubernetes.api.model.kustomize.v1beta1;

import java.lang.Integer;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.util.ArrayList;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;
import java.util.function.Predicate;

 /**
  * Generated
  */
public interface LegacySortOptionsFluent<A extends LegacySortOptionsFluent<A>> extends Fluent<A>{
  public A addToOrderFirst(Integer index,String item);
  public A setToOrderFirst(Integer index,String item);
  public A addToOrderFirst(java.lang.String... items);
  public A addAllToOrderFirst(Collection<String> items);
  public A removeFromOrderFirst(java.lang.String... items);
  public A removeAllFromOrderFirst(Collection<String> items);
  public List<String> getOrderFirst();
  public String getOrderFirst(Integer index);
  public String getFirstOrderFirst();
  public String getLastOrderFirst();
  public String getMatchingOrderFirst(Predicate<String> predicate);
  public Boolean hasMatchingOrderFirst(Predicate<String> predicate);
  public A withOrderFirst(List<String> orderFirst);
  public A withOrderFirst(java.lang.String... orderFirst);
  public Boolean hasOrderFirst();
  public A addToOrderLast(Integer index,String item);
  public A setToOrderLast(Integer index,String item);
  public A addToOrderLast(java.lang.String... items);
  public A addAllToOrderLast(Collection<String> items);
  public A removeFromOrderLast(java.lang.String... items);
  public A removeAllFromOrderLast(Collection<String> items);
  public List<String> getOrderLast();
  public String getOrderLast(Integer index);
  public String getFirstOrderLast();
  public String getLastOrderLast();
  public String getMatchingOrderLast(Predicate<String> predicate);
  public Boolean hasMatchingOrderLast(Predicate<String> predicate);
  public A withOrderLast(List<String> orderLast);
  public A withOrderLast(java.lang.String... orderLast);
  public Boolean hasOrderLast();
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  
}

==> kubernetes-model-kustomize-6.7.2-sources.jar: io/fabric8/kubernetes/api/model/kustomize/v1beta1/LegacySortOptionsFluent.java <==
package io.fabric8.kubernetes.api.model.kustomize.v1beta1;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface LegacySortOptionsFluent<A extends LegacySortOptionsFluent<A>> extends Fluent<A>{
  public A addToOrderFirst(int index,String item);
  public A setToOrderFirst(int index,String item);
  public A addToOrderFirst(java.lang.String... items);
  public A addAllToOrderFirst(Collection<String> items);
  public A removeFromOrderFirst(java.lang.String... items);
  public A removeAllFromOrderFirst(Collection<String> items);
  public List<String> getOrderFirst();
  public String getOrderFirst(int index);
  public String getFirstOrderFirst();
  public String getLastOrderFirst();
  public String getMatchingOrderFirst(Predicate<String> predicate);
  public Boolean hasMatchingOrderFirst(Predicate<String> predicate);
  public A withOrderFirst(List<String> orderFirst);
  public A withOrderFirst(java.lang.String... orderFirst);
  public Boolean hasOrderFirst();
  public A addToOrderLast(int index,String item);
  public A setToOrderLast(int index,String item);
  public A addToOrderLast(java.lang.String... items);
  public A addAllToOrderLast(Collection<String> items);
  public A removeFromOrderLast(java.lang.String... items);
  public A removeAllFromOrderLast(Collection<String> items);
  public List<String> getOrderLast();
  public String getOrderLast(int index);
  public String getFirstOrderLast();
  public String getLastOrderLast();
  public String getMatchingOrderLast(Predicate<String> predicate);
  public Boolean hasMatchingOrderLast(Predicate<String> predicate);
  public A withOrderLast(List<String> orderLast);
  public A withOrderLast(java.lang.String... orderLast);
  public Boolean hasOrderLast();
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  
}
